<?php
date_default_timezone_set('Asia/Jakarta');
 $tgl_time = date("Y-m-d h:i:sa");
 
function url()
{
return sprintf(
"%s://%s%s",
isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off' ? 'https' : 'http',
$_SERVER['SERVER_NAME'],
$_SERVER['REQUEST_URI']
);
}
?>
<!DOCTYPE html>
<html lang="en">
	<head>
	<meta charset="utf-8">
    <meta name="description" content="STIE BII, STIE Bisnis Internasional Indonesia, hadir dengan berbagai program pendidikan yang dirancang khusus untuk karyawan dan profesional. Dapatkan gelar S1 Akuntansi dan S1 Manajemen dengan biaya kuliah yang sangat terjangkau, hanya Rp 600.000 per bulan. Kuliah di STIE BII memungkinkan Anda belajar pada hari sabtu atau melalui kelas ekstensi, cocok untuk yang memiliki jadwal padat, dan tersedia kelas RPL dengan kuliah singkat, edunitas." />
    <meta name="keywords" content="Program Kuliah Malam STIE BII,Kuliah untuk Karyawan Jakarta,Kuliah S1 Manajemen Jakarta,Kuliah S2 Manajemen Jakarta,Universitas Murah Jakarta,Akreditasi STIE BII, Kuliah Sambil Bekerja Jakarta,Kampus untuk Karyawan Jakarta Selatan,Program S1 Manajemen STIE BII Bintaro,Program S2 Manajemen STIE BII,Kampus Terjangkau Jakarta,Kampus Karyawan Jakarta,Sekolah Tinggi Manajemen Jakarta,Biaya Kuliah Terjangkau STIE BII,Kuliah Karyawan di Jakarta,Universitas Jakarta untuk Karyawan,Kuliah Sabtu STIE BII Bintaro,Universitas Murah untuk Karyawan Jakarta,Kampus STIE BII Tambun,Akreditasi STIE BII, S1 Manajemen, stima immi, edunitas, rpl STIE BII, UT, universitas terbuka, S1 Hukum di Jakarta, S1 Komputer di Jakarta, S1 Aktuaria, S1 Sistem dan Teknologi informasi di jakarta selatan, kampus di Tambun, daftar online kuliah karyawan, cara kuliah di STIE BII, jadwal kuliah di STIE BII, biaya kuliah di STIE BII, cara daftar online di STIE BII, jurusan di STIE BII, lokasi kampus STIE BII" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <!--ADS GSC-->


    <title>Pendaftaran &mdash; STIE Bisnis Internasional Indonesia (Kelas Karyawan)</title>
    <meta property="og:title" content="STIE Bisnis Internasional Indonesia (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://stiebii.info">
    <meta property="og:image" content="https://stiebii.info/images/background/hero1.png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="STIE Bisnis Internasional Indonesia menawarkan fleksibilitas jadwal kuliah yang dirancang untuk memenuhi kebutuhan mahasiswa dengan berbagai latar belakang, termasuk profesional yang bekerja. Dengan pendekatan pembelajaran yang adaptif, universitas ini memungkinkan mahasiswa untuk mengatur waktu belajar tanpa mengorbankan komitmen lain. Dukungan dari dosen berpengalaman dan program studi yang relevan menjadikan STIE Bisnis Internasional Indonesia pilihan tepat bagi mereka yang mengutamakan pendidikan berkualitas dengan jadwal yang fleksibel.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="STIE Bisnis Internasional Indonesia (Kelas Karyawan)">
    <meta name="twitter:description" content="STIE Bisnis Internasional Indonesia adalah institusi pendidikan tinggi yang berkomitmen untuk mencetak generasi unggul melalui program akademik berkualitas dan inovatif. Dengan pendekatan yang berfokus pada pengembangan keterampilan praktis dan integritas akademik, STIE Bisnis Internasional Indonesia menyediakan berbagai fakultas dan program studi yang relevan dengan kebutuhan industri dan masyarakat. Didukung oleh tenaga pengajar profesional dan fasilitas modern, universitas ini menjadi tempat yang ideal bagi mahasiswa untuk meraih prestasi dan membangun karier yang gemilang.">
    <meta name="twitter:domain" content="https://stiebii.info">
    <meta property="og:image" content="https://stiebii.info/images/background/hero1.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="STIE BII | Kuliah Karyawan K2" />


    <link rel="apple-touch-icon" sizes="57x57" href="https://stiebii.info//images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="https://stiebii.info//images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="https://stiebii.info//images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="https://stiebii.info//images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="https://stiebii.info//images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="https://stiebii.info//images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="https://stiebii.info//images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="https://stiebii.info//images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="https://stiebii.info//images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192"  href="https://stiebii.info//images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="https://stiebii.info//images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="https://stiebii.info//images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="https://stiebii.info//images/favicons/favicon-16x16.png">
    <link rel="manifest" href="https://stiebii.info//images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="https://stiebii.info//images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">
	
<script src='https://www.google.com/recaptcha/api.js'></script>
	</head>
	
	<style>
		@import url("https://fonts.googleapis.com/css?family=Poppins:200i,400&display=swap");
		*,
		*::before,
		*::after {
			box-sizing: border-box;
		}
		body {
			font-family: "Poppins", sans-serif;
			font-size: 1rem;
			font-weight: 400;
			line-height: 1.5;
			background-color: #f2f1f7;
			margin: 0;
		}
		h1 {
			font-weight: 400;
			line-height: 1.5;
		}
		p {
			font-size: 1.2rem;
		}
		h1,
		p {
			margin-top: 0;
			margin-bottom: 1rem;
		}
		label {
			display: flex;
			align-items: center;
			font-size: 1.2rem;
			margin-bottom: 0.8rem;
		}
		input,
		button,
		select,
		textarea {
			margin: 0;
			font-family: inherit;
			font-size: inherit;
			line-height: inherit;
		}
		button {
			border: none;
			border: 1px solid #868686;
		}
		.container {
			width: 83%;
			margin: 3.125rem auto 0 auto;
		}
		@media (min-width: 576px) {
			.container {
				max-width: 540px;
			}
		}

		@media (min-width: 768px) {
			.container {
				max-width: 720px;
			}
		}
		.header {
			padding: 0 0.8rem;
			margin-bottom: 1.875rem;
		}
		.description {
			font-style: italic;
			font-weight: 200;
		}
		.clue {
			margin-left: 0.25rem;
			font-size: 0.9rem;
			color: #c2c2c2;
		}

		.text-center {
			text-align: center;
		}

		/* form */

		form {
			background: #fff;
			padding: 2.5rem 0.625rem;
			border-radius: 0.25rem;
		}

		@media (min-width: 480px) {
			form {
				padding: 2.5rem;
			}
		}

		.form-group {
			margin: 0 auto 1.25rem auto;
			padding: 0.25rem;
		}

		.form-control {
			display: block;
			width: 100%;
			height: 2.4rem;
			padding: 0.375rem 0.75rem;
			color: #91918f;
			background-color: #e4e3ea;
			background-clip: padding-box;
			border: 0;
			border-radius: 0.25rem;
			transition: border 0.8s ease-in-out;
		}

		.form-control:focus {
			border: 1px solid #868686;
			outline: 0;
		}

		.input-radio,
		.input-checkbox {
			display: inline-block;
			margin-right: 0.6rem;
			min-height: 1.5rem;
			min-width: 1.25rem;
		}

		.input-textarea {
			min-height: 120px;
			width: 100%;
			padding: 0.625rem;
			resize: vertical;
			border: 0;
			border: 1px solid #868686;
			outline: none;
		}

		.submit-button {
			display: block;
			width: 100%;
			padding: 0.75rem;
			background: #e7e7e7;
			color: inherit;
			border-radius: 2px;
			cursor: pointer;
		}
		
		   /* already defined in bootstrap4 */
	    .text-xs-center {
	        text-align: center;
	    }

	    .g-recaptcha {
	        display: inline-block;
	    }
	</style>
	<body>
		<div class="container">
			<header class="header">
				<h1 id="title" class="text-center">Form Pendaftaran Online</h1>
				
			</header>
			<form  method="POST" action="proses-pendaftaran.php">
			    
			<div class="form-group">
            <input
            type="text"
            name="nama_kampus"
            value="<?= url() ?>"
            class="form-control"
            readonly
            />
            </div>
						<div class="form-group">
					<label id="number-label" for="email"
						>Pilih Jurusan<span style="color: #ff0000">*</span></label
					>
				<select class="form-control" name=jurusan required>
				    <option >-- Pilih Jurusan --</option>
				    <!--FAKULTAS KEGURUAN DAN ILMU PENDIDIKAN -->
				    <optgroup label="FAKULTAS KEGURUAN DAN ILMU PENDIDIKAN">
				    <option value="S1 PENDIDIKAN GURU SEKOLAH DASAR">S1 PENDIDIKAN GURU SEKOLAH DASAR</option>
                    <option value="S1 PENDIDIKAN KONSELING ">S1 PENDIDIKAN KONSELING </option>
                    <option value="S1 PENDIDIKAN PKN">S1 PENDIDIKAN PKN</option>
                    <option value="S1 PENDIDIKAN GURU PAUD">S1 PENDIDIKAN GURU PAUD</option>
                    <option value="S1 PENDIDIKAN LUAR BIASA">S1 PENDIDIKAN LUAR BIASA</option>
                    <option value="S1 PENDIDIKAN MATEMATIKA">S1 PENDIDIKAN MATEMATIKA</option>
                    <option value="S1 PENDIDIKAN BAHASA&SASTRA INDONESIA">S1 PENDIDIKAN BAHASA&SASTRA INDONESIA</option>
                    <option value="S1 PENDIDIKAN SEJARAH">S1 PENDIDIKAN SEJARAH</option>
                    <option value="S1 PENDIDIKAN BAHASA INGGRIS">S1 PENDIDIKAN BAHASA INGGRIS</option>
                    <option value="S1 PENDIDIKAN VOKASIONAL TEKNOLOGI OTOMOTIF">S1 PENDIDIKAN VOKASIONAL TEKNOLOGI OTOMOTIF</option>
                    <option value="S2 ILMU PENGETAHUAN SOSIAL">S2 ILMU PENGETAHUAN SOSIAL</option>
                    <option value="S2 PENDIDIKAN DASAR">S2 PENDIDIKAN DASAR</option>
                    <optgroup/>
				    <!--FAKULTAS BISNIS DAN HUKUM-->
				    <optgroup label="FAKULTAS BISNIS DAN HUKUM">
				    <option value="S1 AKUTANSI">S1 AKUTANSI</option>
                    <option value="S1 MANAJEMEN">S1 MANAJEMEN</option>
                    <option value="S1 BISNIS DIGITAL">S1 BISNIS DIGITAL</option>
                    <option value="S1 HUKUM BISNIS">S1 HUKUM BISNIS</option>
                    <option value="S2 MANAJEMEN">S2 MANAJEMEN</option>
                    <optgroup/>
                    <!--FAKULTAS PERTANIAN -->
                    <optgroup label="FAKULTAS PERTANIAN">
                    <option value="S1 AGROTEKNOLOGI">S1 AGROTEKNOLOGI</option>
                    <option value="S1 TEKNOLOGI HASIL PERTANIAN">S1 TEKNOLOGI HASIL PERTANIAN</option>
                    <optgroup/>
                    <!--FAKULTAS SAINS DAN TEKNOLOGI -->
                    <optgroup label="FAKULTAS SAINS DAN TEKNOLOGI">
                    <option value="S1 INFORMATIKA">S1 INFORMATIKA</option>
                    <option value="S1 ARSITEKTUR">S1 ARSITEKTUR</option>
                    <option value="S1 TEKNIK INDUSTRI">S1 TEKNIK INDUSTRI</option>
                    <option value="S1 FARMASI">S1 FARMASI</option>
                    <option value="S1 TEKNIK BIOMEDIS">S1 TEKNIK BIOMEDIS</option>
                    <option value="D4 TEKNIK REKAYASA ELEKTRO MEDIS">D4 TEKNIK REKAYASA ELEKTRO MEDIS</option>
                    <option value="S1 ILMU KEOLAHRAGAAN">S1 ILMU KEOLAHRAGAAN</option>
                    <option value="S1 SISTEM INFORMASI">S1 SISTEM INFORMASI</option>
                    <option value="S1 GIZI">S1 GIZI</option>
                    <optgroup/>
                    <!--BIAYA RPL-->
                    <optgroup label="BIAYA RPL">
                    <option value="Biaya RPL">Biaya RPL</option>
                    <optgroup/>
				</select>
				</div>
				
				<div class="form-group">
					<p>Kelas<span style="color: #ff0000">*</span></p>
					<select
						id="dropdown"
						name="kelas"
						class="form-control"
						required
					>
						<option disabled selected value>
							-- Pilih Kelas --
						</option>
						<option value="Kelas Karyawan">Kelas Karyawan</option>
						<option value="Kelas Reguler Pagi">Kelas Reguler Pagi</option>
					</select>
				</div>
				
				<div class="form-group">
					<label id="name-label" for="name"
						>Nama Lengkap
						<span style="color: #ff0000">*</span></label
					>
					<input
						type="text"
						name="nama"
						id="name"
						class="form-control"
						placeholder="Nama Sesuai KTP"
						required
					/>
				</div>
				<div class="form-group">
					<p>Jenis Kelamin</p>
					<label>
						<input
							name="jk"
							value="laki-laki"
							type="radio"
							class="input-radio"
							checked
						/>Laki-laki</label
					>
					<label>
						<input
							name="jk"
							value="perempuan"
							type="radio"
							class="input-radio"
						/>Perempuan</label
					>
				</div>
			
				<div class="form-group">
					<label id="number-label" for="number"
						>Alamat<span style="color: #ff0000">*</span></label
					>
					<input
						type="text"
						name="alamat"
						id="number"
					
						class="form-control"
						placeholder="Sesuai KTP"
					/>
				</div>
				<div class="form-group">
					<label id="number-label" for="number"
						>Tempat Lahir<span style="color: #ff0000"
							>*</span
						></label
					>
					<input
						type="text"
						name="tempat_lahir"
						id="number"
						
						class="form-control"
						placeholder=""
					/>
				</div>
				<div class="form-group">
					<label id="number-label" for="number"
						>Tanggal Lahir<span style="color: #ff0000"
							>*</span
						></label
					>
					<input
						type="date"
						name="tanggal_lahir"
						id="number"
						
						class="form-control"
						placeholder=""
					/>
				</div>
			
				<div class="form-group">
					<label id="number-label" for="no_war"
						>Nomor WhatsApp/HP<span style="color: #ff0000"
							>*</span
						></label
					>
					<input
						type="number"
						name="no_wa"
						class="form-control"
						placeholder=""
						required
					/>
				</div>
				<div class="form-group">
					<label id="number-label" for="email"
						>Email<span style="color: #ff0000">*</span></label
					>
					<input
						type="email"
						name="email"
					
						class="form-control"
						placeholder="Email"
					/>
				</div>
		
			
				<div class="form-group">
					<p>Lulusan<span style="color: #ff0000">*</span></p>
					<select
						id="dropdown"
						name="lulusan"
						class="form-control"
						required
					>
						<option disabled selected value>
							-- Pilih Lulusan --
						</option>
						<option value="SMA/MA/SMK/Sederajat">SMA/MA/SMK/Sederajat</option>
						<option value="D3/Sederajat">D3/Sederajat</option>
						<option value="Paket C">Paket C</option>
						<option value="S1/D4/Sederajat">S1/D4/Sederajat</option>
					</select>
				</div>
					<input
						type="hidden"
						name="tgl_daftar"
						value="<?= $tgl_time?>"
					
					
					/>
					<div class="form-group col-sm-12 text-center">
					    
					<!--<div class="g-recaptcha" data-sitekey="6LcXEmYrAAAAAC3Pj9RavaCFS-atJshxWZx8OteJ"></div>-->
					</div>
				
				
				<div class="form-group">
				<button type="submit" name="daftar" value="daftar" class="submit-button" />Daftar</button>
				</div>
			</form>
		</div>
	</body>
</html>
